@@ -6,7 +6,7 @@
 #' getting all species in a family.
 #'
 #' @export
-#' @param x Vector of taxa names (character) or IDs (character or numeric)
+#' @param sci_id Vector of taxa names (character) or IDs (character or numeric)
 #' to query.
 #' @param db character; database to query. One or more of `itis`,
 #' `ncbi`, `worms`, or `bold`. Note that each taxonomic data
@@ -18,6 +18,7 @@
 #' rows are considered. Note that this parameter is ignored if you pass in a
 #' taxonomic id of any of the acceptable classes: tsn. NCBI has a
 #' method for this function but rows doesn't work.
+#' @param x Deprecated, see `sci_id`
 #' @param ... Further args passed on to [ritis::hierarchy_down()],
 #' [ncbi_children()], [worrms::wm_children()], [bold_children()]
 #' See those functions for what parameters can be passed on.
@@ -51,7 +52,7 @@
 #' children("Salmo", db = 'bold')
 #'
 #' # Plug in IDs
-#' (id <- get_wormsid("Platanista"))
+#' (id <- get_wormsid("Gadus"))
 #' children(id)
 #'
 #' # Many taxa
@@ -78,41 +79,43 @@ children <- function(...){
 
 #' @export
 #' @rdname children
-children.default <- function(x, db = NULL, rows = NA, ...) {
+children.default <- function(sci_id, db = NULL, rows = NA, x = NULL, ...) {
   nstop(db)
+  pchk(x, "sci_id")
+  if (!is.null(x)) sci_id <- x
   results <- switch(
     db,
     itis = {
-      id <- process_children_ids(x, db, get_tsn, rows = rows, ...)
-      stats::setNames(children(id, ...), x)
+      id <- process_children_ids(sci_id, db, get_tsn, rows = rows, ...)
+      stats::setNames(children(id, ...), sci_id)
     },
 
     ncbi = {
-      if (all(grepl("^[[:digit:]]*$", x))) {
-        id <- x
+      if (all(grepl("^[[:digit:]]*$", sci_id))) {
+        id <- sci_id
         class(id) <- "uid"
-        stats::setNames(children(id, ...), x)
+        stats::setNames(children(id, ...), sci_id)
       } else {
-        out <- ncbi_children(name = x, ...)
-        structure(out, class = 'children', db = 'ncbi', .Names = x)
+        out <- ncbi_children(name = sci_id, ...)
+        structure(out, class = 'children', db = 'ncbi', .Names = sci_id)
       }
     },
 
     worms = {
-      id <- process_children_ids(x, db, get_wormsid, rows = rows, ...)
-      stats::setNames(children(id, ...), x)
+      id <- process_children_ids(sci_id, db, get_wormsid, rows = rows, ...)
+      stats::setNames(children(id, ...), sci_id)
     },
 
     bold = {
-      id <- process_children_ids(as.character(x), db, get_boldid,
+      id <- process_children_ids(as.character(sci_id), db, get_boldid,
         rows = rows, ...)
-      stats::setNames(children(id, ...), x)
+      stats::setNames(children(id, ...), sci_id)
     },
 
     stop("the provided db value was not recognised", call. = FALSE)
   )
 
-  set_output_types(results, x, db)
+  set_output_types(results, sci_id, db)
 }
 
 # Ensure that the output types are consistent when searches return nothing
@@ -149,7 +152,7 @@ set_output_types <- function(x, x_names, db){
 
 process_children_ids <- function(input, db, fxn, ...){
   g <- tryCatch(as.numeric(as.character(input)), warning = function(e) e)
-  if (inherits(g, "condition")) eval(fxn)(input, ...)
+  if (inherits(g, "condition")) return(eval(fxn)(input, ...))
   if (is.numeric(g) || is.character(input) && all(grepl("[[:digit:]]", input))) {
     as_fxn <- switch(db, itis = as.tsn, worms = as.wormsid, bold = as.boldid)
     as_fxn(input, check = FALSE)
@@ -160,7 +163,7 @@ process_children_ids <- function(input, db, fxn, ...){
 
 #' @export
 #' @rdname children
-children.tsn <- function(x, db = NULL, ...) {
+children.tsn <- function(sci_id, db = NULL, ...) {
   warn_db(list(db = db), "itis")
   fun <- function(y){
     # return NA if NA is supplied
@@ -170,8 +173,8 @@ children.tsn <- function(x, db = NULL, ...) {
 		  out <- ritis::hierarchy_down(y, ...)
     }
   }
-  out <- lapply(x, fun)
-  names(out) <- x
+  out <- lapply(sci_id, fun)
+  names(out) <- sci_id
   class(out) <- 'children'
   attr(out, 'db') <- 'itis'
   return(out)
@@ -188,7 +191,7 @@ df2dt2tbl <- function(x) {
 
 #' @export
 #' @rdname children
-children.wormsid <- function(x, db = NULL, ...) {
+children.wormsid <- function(sci_id, db = NULL, ...) {
   warn_db(list(db = db), "worms")
   fun <- function(y){
     # return NA if NA is supplied
@@ -211,8 +214,8 @@ children.wormsid <- function(x, db = NULL, ...) {
       )
     }
   }
-  out <- lapply(x, fun)
-  names(out) <- x
+  out <- lapply(sci_id, fun)
+  names(out) <- sci_id
   class(out) <- 'children'
   attr(out, 'db') <- 'worms'
   return(out)
@@ -220,7 +223,7 @@ children.wormsid <- function(x, db = NULL, ...) {
 
 #' @export
 #' @rdname children
-children.ids <- function(x, db = NULL, ...) {
+children.ids <- function(sci_id, db = NULL, ...) {
   fun <- function(y, ...){
     # return NA if NA is supplied
     if (is.na(y)) {
@@ -230,19 +233,19 @@ children.ids <- function(x, db = NULL, ...) {
     }
     return(out)
   }
-  out <- lapply(x, fun)
+  out <- lapply(sci_id, fun)
   class(out) <- 'children_ids'
   return(out)
 }
 
 #' @export
 #' @rdname children
-children.uid <- function(x, db = NULL, ...) {
+children.uid <- function(sci_id, db = NULL, ...) {
   warn_db(list(db = db), "uid")
-  out <- if (is.na(x)) {
-    stats::setNames(list(ncbi_blank), x)
+  out <- if (is.na(sci_id)) {
+    stats::setNames(list(ncbi_blank), sci_id)
   } else {
-    ncbi_children(id = x, ambiguous = TRUE, ...)
+    ncbi_children(id = sci_id, ambiguous = TRUE, ...)
   }
   class(out) <- 'children'
   attr(out, 'db') <- 'ncbi'
@@ -251,12 +254,12 @@ children.uid <- function(x, db = NULL, ...) {
 
 #' @export
 #' @rdname children
-children.boldid <- function(x, db = NULL, ...) {
+children.boldid <- function(sci_id, db = NULL, ...) {
   warn_db(list(db = db), "bold")
-  out <- if (is.na(x)) {
-    stats::setNames(list(bold_blank), x)
+  out <- if (is.na(sci_id)) {
+    stats::setNames(list(bold_blank), sci_id)
   } else {
-    bold_children(id = x, ...)
+    bold_children(id = sci_id, ...)
   }
   class(out) <- 'children'
   attr(out, 'db') <- 'bold'
