@@ -3,6 +3,7 @@ test_that("iucn_summary returns the correct value", {
   if (Sys.getenv("IUCN_REDLIST_KEY") == "") {
     skip("No IUCN api key so test not run.")
   }
+  skip_on_cran()
 
   vcr::use_cassette("iucn_summary", {
     temp <- iucn_summary(c("Panthera uncia", "Lynx lynx"))
@@ -18,6 +19,7 @@ test_that("iucn_summary gives expected result for lots of names", {
   if (Sys.getenv("IUCN_REDLIST_KEY") == "") {
     skip("No IUCN api key so test not run.")
   }
+  skip_on_cran()
 
   vcr::use_cassette("iucn_summary_other_egs", {
     aa <- iucn_summary("Abies koreana")
@@ -31,7 +33,7 @@ test_that("iucn_summary gives expected result for lots of names", {
   }, preserve_exact_body_bytes = TRUE)
 
   expect_equal(aa$`Abies koreana`$status, "EN")
-  expect_equal(bb$`Xylopia collina`$status, "EN")
+  expect_equal(bb$`Xylopia collina`$status, "NT")
   expect_equal(cc$`Brugmansia versicolor`$status, "EW")
   expect_equal(dd$`Achatinella buddii`$status, "EX")
   expect_equal(ee$`Annona hystricoides`$status, "CR")
@@ -39,12 +41,3 @@ test_that("iucn_summary gives expected result for lots of names", {
   expect_equal(gg$`Cyornis lemprieri`$status, "NT")
   expect_equal(hh$`Frailea pumila`$status, "LC")
 })
-
-context("iucn_summary: curl options work")
-test_that("iucn_summary curl options work", {
-  skip_on_cran()
-  if (Sys.getenv("IUCN_REDLIST_KEY") == "") {
-    skip("No IUCN api key so test not run.")
-  }
-  expect_error(iucn_summary("Abies koreana", timeout_ms = 1, messages = FALSE))
-})
