@@ -3,9 +3,9 @@ context("tax_name")
 test_that("tax_name: ncbi", {
   skip_on_cran() # uses secrets
   vcr::use_cassette("tax_name_ncbi", {
-    tmp_ncbi  <- tax_name(query = "Baetis", get = c("family", "order"),
+    tmp_ncbi  <- tax_name("Baetis", get = c("family", "order"),
                           db = "ncbi", messages=FALSE)
-    tmp_ncbi2 <- tax_name(query = c("Helianthus annuus", 'Baetis rhodani'),
+    tmp_ncbi2 <- tax_name(c("Helianthus annuus", 'Baetis rhodani'),
                           get = c("genus", "kingdom"), db = "ncbi", messages=FALSE)
   })
 
@@ -19,9 +19,9 @@ test_that("tax_name: ncbi", {
 test_that("tax_name: NA's", {
   skip_on_cran() # uses secrets
   vcr::use_cassette("tax_name_na", {
-    tmp_na2 <- tax_name(query=c("Helianthus annuus", 'xxxx'),
+    tmp_na2 <- tax_name(c("Helianthus annuus", 'xxxx'),
                         get=c("family", "order"), db="ncbi", messages=FALSE)
-    tmp_na3 <- sw(tax_name(query = c("Helianthus annuus", 'xxxx'), rows = 1,
+    tmp_na3 <- sw(tax_name(c("Helianthus annuus", 'xxxx'), rows = 1,
                         get = c("family", "order"), db="itis", messages = FALSE))
   })
 
@@ -34,8 +34,9 @@ test_that("tax_name: NA's", {
 })
 
 test_that("tax_name: itis", {
+  skip_on_cran()
   vcr::use_cassette("tax_name_itis", {
-    tmp_itis <- sw(tax_name(query = "Helianthus annuus", rows = 1,
+    tmp_itis <- sw(tax_name("Helianthus annuus", rows = 1,
                         get = c("family", "order"), db="itis", messages = FALSE))
   })
 
@@ -60,7 +61,7 @@ test_that("tax_name: rows arg", {
 test_that("tax_name accepts ask-argument", {
   skip_on_cran() # uses secrets
   vcr::use_cassette("tax_name_arg_arg", {
-    x <- sw(tax_name(query = "Dugesia", get = "family", db = "ncbi",
+    x <- sw(tax_name("Dugesia", get = "family", db = "ncbi",
                              ask = FALSE, messages = FALSE))$family
   })
 
